@@ -14,4 +14,9 @@ class wi_income_subtractions(Variable):
         "https://www.revenue.wi.gov/TaxForms2022/2022-ScheduleSB-Inst.pdf"
     )
     defined_for = StateCode.WI
-    adds = "gov.states.wi.tax.income.subtractions.sources"
+
+    def formula(tax_unit, period, parameters):
+        p = parameters(period).gov.states.wi.tax.income.subtractions
+        total_subtractions = add(tax_unit, period, p.sources)
+        # Prevent negative subtractions from acting as additions
+        return max_(0, total_subtractions)
